#ifndef __MACROS_H
#define __MACROS_H
//-----------------------------------------------------------------------------

#define BIT(x) (1 << (x)) // Bitwert definieren

#define __DISABLE_INTERRUPTS() \
  __asm {mrs R12,cpsr} \
  __asm {orr R12,R12,#0x80} \
  __asm {msr cpsr_c,R12} \

#define __ENABLE_INTERRUPTS() \
  __asm {mrs R12,cpsr} \
  __asm {bic R12,R12,#0x80} \
  __asm {msr cpsr_c,R12) \

// Makros fr Interrupt-Nesting
#define __ENABLE_NESTED_INTERRUPT() \
  __asm {MRS     LR,SPSR     } /* Copy SPSR_irq to LR     */ \
  __asm {STMFD   SP!,{LR}    } /* Save SPSR_irq           */ \
  __asm {MSR     CPSR_c,#0x1F} /* Enable IRQ (Sys Mode)   */ \
  __asm {STMFD   SP!,{LR}    } /* Save LR                 */ \

#define __DISABLE_NESTED_INTERRUPT() \
  __asm {LDMFD   SP!,{LR}    } /* Restore LR              */ \
  __asm {MSR     CPSR_c,#0x92} /* Disable IRQ (IRQ Mode)  */ \
  __asm {LDMFD   SP!,{LR}    } /* Restore SPSR_irq to LR  */ \
  __asm {MSR     SPSR_cxsf,LR} /* Copy LR to SPSR_irq     */ \

#define NOP() __asm {nop}
//-----------------------------------------------------------------------------

#endif
